@@ -21,7 +21,7 @@ use Thrift::HttpClient;
 use Thrift::BinaryProtocol;
 use Data::Dumper;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 our $EN_DEV_TOKEN_PAGE = 
     "http://dev.evernote.com/documentation/cloud/chapters/" .
@@ -197,6 +197,14 @@ sub horrid_thrift_client_error_diagnostics {
     }
 }
 
+###########################################
+sub sdk {
+###########################################
+    my( $self, $name ) = @_;
+
+    return __PACKAGE__ . "::" . $name;
+}
+
 1;
 
 __END__
@@ -305,19 +313,57 @@ C<listNotebooks()> or C<createNote()>.
 
 One thing to keep in mind when using this library is that the original
 C<EDAMxxx> namespace of the Evernote API has been converted to 
-C<Net::Evernote::Simple::EDAMxxx> to avoid collisions. See the example
-below to get an idea on how to use it. Consult the official Evernote
+C<Net::Evernote::Simple::EDAMxxx> to avoid collisions. 
+
+To obtain the fully qualified module names, you can use the special 
+C<sdk()> method, so instead of saying
+
+    my $filter =
+      Net::Evernote::Simple::EDAMNoteStore::NoteFilter->new();
+
+you can just as well say
+
+    my $filter = $en->sdk( "EDAMNoteStore::NoteFilter" )->new();
+
+See the example
+below to get an idea on how to use this API. Consult the official Evernote
 API documentation at the link listed above for details on data structures
 used and parameters needed.
 
-=head1 EXAMPLE
+=head1 EXAMPLE: Finding and printing notes
 
-   # add a note with a JPG image to notebook "Recipes"
-
-    #!/usr/local/bin/perl
-    use strict;
-    use warnings;
+    use Net::Evernote::Simple;
+    my $en = Net::Evernote::Simple->new();
     
+    if( ! $en->version_check() ) {
+      die "Evernote API version out of date!";
+    }
+    
+    my $note_store = $en->note_store() or
+       die "getting notestore failed: $@";
+    
+    my $filter = $en->sdk(
+      "EDAMNoteStore::NoteFilter" )->new(
+        { words => "foo bar baz" } );
+    
+    my $offset    = 0;
+    my $max_notes = 100;
+    
+    my $result = $note_store->findNotes(
+        $en->{ dev_token },
+        $filter,
+        $offset,
+        $max_notes
+    );
+    
+    for my $hit ( @{ $result->{ notes } } ) {
+      my $note = $note_store->getNote( 
+       $en->{ dev_token }, $hit->{ guid }, 1 );
+      print $note->{ content };
+    }
+
+=head1 EXAMPLE: Add a note with a JPG image to notebook "Recipes"
+
     use Net::Evernote::Simple;
     use Sysadm::Install qw( slurp );
     use Digest::MD5 qw( md5_hex );
